@@ -239,6 +239,9 @@ RESOURCEUNAVAILABLE_ACCOUNTBALANCENOTENOUGH = 'ResourceUnavailable.AccountBalanc
 # 备份已被其它任务锁住，暂时不能执行该操作。
 RESOURCEUNAVAILABLE_BACKUPLOCKEDERROR = 'ResourceUnavailable.BackupLockedError'
 
+# 备份还原规格不支持。
+RESOURCEUNAVAILABLE_BACKUPSPECERROR = 'ResourceUnavailable.BackupSpecError'
+
 # 备份状态异常，暂不能执行该操作。备份可能已过期或已被删除。
 RESOURCEUNAVAILABLE_BACKUPSTATUSABNORMAL = 'ResourceUnavailable.BackupStatusAbnormal'
 
@@ -326,5 +329,8 @@ UNSUPPORTEDOPERATION_ISAUTORENEWERROR = 'UnsupportedOperation.IsAutoRenewError'
 # 实例版本过低。
 UNSUPPORTEDOPERATION_LIMITPROXYVERSION = 'UnsupportedOperation.LimitProxyVersion'
 
+# 实例版本过低
+UNSUPPORTEDOPERATION_LOWVERSION = 'UnsupportedOperation.LowVersion'
+
 # 只有集群版实例支持导出备份。
 UNSUPPORTEDOPERATION_ONLYCLUSTERINSTANCECANEXPORTBACKUP = 'UnsupportedOperation.OnlyClusterInstanceCanExportBackup'
